/*
    main.c
    Copyright (C) 2007  

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* ============================================================================
   Markus Fulde                                                      03.01.2011
   ----------------------------------------------------------------------------
   
   Der Sourcecode zum RF-Betrieb des SCART-Adapters stammt aus dem Forum
                        http://www.bettyhacks.com
   und wurde speziell fr das Projekt StarLight angepasst. Dabei wurden nicht
   bentigte Funktionen aus Grnden der Speichergre und Laufzeitoptimierung
   komplett entfernt.
   
   Der in dieser Version nun vorliegende Programmcode dient zur Kommunikation
   der Betty ber Funk mit dem Master-Modul des StarLight-Projekts. Hierbei
   werden Daten 1:1 durchgeroutet. Die Funktionen beschrnken sich auf den
   Paket-Typ RF_PACKET_BINARY.
   ============================================================================
   Historie:
   03.01.2010  Version 1  Erste vollstndige Version nach Optimierung
   
   ============================================================================
*/

/* =================================== Includes ============================ */

#include <P89LPC932.h>  // special function register declarations
                        // for the Philips P89C931 device

#include "rf.h"
#include "serial.h"
#include "cmd.h"
#include "cc1100.h"
#include "timer.h"


/* ================== Datentypen und Variablendefinitionen ================= */

__sfr __at (0xAD) CMP2_   ;


/* ======================= Funktionen und Programmcode ===================== */

/*
   ----------------------------------------------------------------------------
   Funktion: main
   ----------------------------------------------------------------------------
*/
void main(void)
{
   /* ----- lokale Variablen ----- */
   unsigned char x;
   unsigned char len;


   /* ----- Programmcode ----- */
   P0M1 &= 0x6c;
   P0M2 |= 0x92;
   P0 = 0x83;
   
   P1M1 &= 0x3e;
   P1M2 |= 0xcd;
   P1 = 0xcd;
   
   P3M1 &= 0xfe;
   P3M2 |= 0x01;
   P3 = 0;
   
   initTimer0();
   initSerial();
   RF_init();
   RF_startIRQ();
   
   EA = 1;
  
   // Ready senden um Bereitschaft zu signalisieren
   send_byte(0x01);
   
   // Fr StarLight wird auch Terminal deaktiviert da Funktion abgespeckt auf binr

   len =0;
   
   while (1)
   {
      //Binary mode:
      //============
      // Kommandos:
      // 0x00                                    NOP
      // 0x01 <n> <data_1> ... <data_n>          transmitt n Bytes (n<=61)
      //
      // Rckgabewerte:
      // 0x00                                    syntax error
      // 0x01                                    ready
      // 0x02 <n> <data_1> ... <data_n>          n bytes data received ber Funktion RF_PACKET_BINARY
      // 0x03 <n> <data_1> ... <data_n>          n bytes data received ber Funktion DEFAULT. Die ersten Bytes beinhalten Frame-Info

      if (inbuflen)
      {
         x=get_inbuf();
         switch(x)
         {
            case 0x00:
               send_byte(0x01);     // READY als Antwort an Master senden
               break;

            case 0x01:
                cmdStarLightSendRF( );
                send_byte(0x01);     // READY als Antwort an Master senden
               break;

            default:
               send_byte(0x00);
               break;
         }
      }
   }
}
/* ----- Ende main --------------------------------------------------------- */

/* =================================== Ende ================================ */

